@@ -94,6 +94,7 @@ class Client:
 
     def fetch(self, endpoint="/", endpoint_type="pd", exceptions={}) -> dict: # exception: code: {Exception, Message}
         '''Get data from a pd/glz/local endpoint'''
+        data = None
         if endpoint_type in ["pd", "glz", "shared"]:
             response = requests.get(f'{self.base_url_glz if endpoint_type == "glz" else self.base_url if endpoint_type == "pd" else self.base_url_shared if endpoint_type == "shared" else self.base_url}{endpoint}', headers=self.headers)
             
@@ -128,11 +129,15 @@ class Client:
             return data
         if data["httpStatus"] == 400:
             # if headers expire (i dont think they ever do but jic), refresh em!
-            self.puuid, self.headers, self.local_headers = self.__get_headers()
+            if self.auth is None:
+                self.puuid, self.headers, self.local_headers = self.__get_headers()
+            else:
+                self.puuid, self.headers, self.local_headers = self.auth.authenticate()
             return self.fetch(endpoint=endpoint, endpoint_type=endpoint_type)
 
     def post(self, endpoint="/", endpoint_type="pd", json_data={}, exceptions={}) -> dict:
         '''Post data to a pd/glz endpoint'''
+        data = None
         response = requests.post(f'{self.base_url_glz if endpoint_type == "glz" else self.base_url}{endpoint}', headers=self.headers, json=json_data)
 
         # custom exceptions for http status codes
@@ -177,7 +182,7 @@ class Client:
         Content_FetchContent
         Get names and ids for game content such as agents, maps, guns, etc.
         '''
-        data = self.fetch(endpoint="/content-service/v2/content",endpoint_type="shared")
+        data = self.fetch(endpoint="/content-service/v3/content",endpoint_type="shared")
         return data
     
     def fetch_account_xp(self) -> dict:
